/**
 * Copyright (c) 2022, Salesforce, Inc.,
 * All rights reserved.
 * For full license text, see the LICENSE.txt file
 */

import { serializeStructuredKey, ingestShape, deepFreeze, buildNetworkSnapshotCachePolicy as buildNetworkSnapshotCachePolicy$1, typeCheckConfig as typeCheckConfig$1, StoreKeyMap, createResourceParams as createResourceParams$1 } from '@luvio/engine';

const { hasOwnProperty: ObjectPrototypeHasOwnProperty } = Object.prototype;
const { keys: ObjectKeys, create: ObjectCreate } = Object;
const { stringify: JSONStringify$1 } = JSON;
const { isArray: ArrayIsArray$1 } = Array;
/**
 * Validates an adapter config is well-formed.
 * @param config The config to validate.
 * @param adapter The adapter validation configuration.
 * @param oneOf The keys the config must contain at least one of.
 * @throws A TypeError if config doesn't satisfy the adapter's config validation.
 */
function validateConfig(config, adapter, oneOf) {
    const { displayName } = adapter;
    const { required, optional, unsupported } = adapter.parameters;
    if (config === undefined ||
        required.every(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify ${required.sort().join(', ')}`);
    }
    if (oneOf && oneOf.some(req => ObjectPrototypeHasOwnProperty.call(config, req)) === false) {
        throw new TypeError(`adapter ${displayName} configuration must specify one of ${oneOf.sort().join(', ')}`);
    }
    if (unsupported !== undefined &&
        unsupported.some(req => ObjectPrototypeHasOwnProperty.call(config, req))) {
        throw new TypeError(`adapter ${displayName} does not yet support ${unsupported.sort().join(', ')}`);
    }
    const supported = required.concat(optional);
    if (ObjectKeys(config).some(key => !supported.includes(key))) {
        throw new TypeError(`adapter ${displayName} configuration supports only ${supported.sort().join(', ')}`);
    }
}
function untrustedIsObject(untrusted) {
    return typeof untrusted === 'object' && untrusted !== null && ArrayIsArray$1(untrusted) === false;
}
function areRequiredParametersPresent(config, configPropertyNames) {
    return configPropertyNames.parameters.required.every(req => req in config);
}
const snapshotRefreshOptions = {
    overrides: {
        headers: {
            'Cache-Control': 'no-cache',
        },
    }
};
/**
 * A deterministic JSON stringify implementation. Heavily adapted from https://github.com/epoberezkin/fast-json-stable-stringify.
 * This is needed because insertion order for JSON.stringify(object) affects output:
 * JSON.stringify({a: 1, b: 2})
 *      "{"a":1,"b":2}"
 * JSON.stringify({b: 2, a: 1})
 *      "{"b":2,"a":1}"
 * @param data Data to be JSON-stringified.
 * @returns JSON.stringified value with consistent ordering of keys.
 */
function stableJSONStringify(node) {
    // This is for Date values.
    if (node && node.toJSON && typeof node.toJSON === 'function') {
        // eslint-disable-next-line no-param-reassign
        node = node.toJSON();
    }
    if (node === undefined) {
        return;
    }
    if (typeof node === 'number') {
        return isFinite(node) ? '' + node : 'null';
    }
    if (typeof node !== 'object') {
        return JSONStringify$1(node);
    }
    let i;
    let out;
    if (ArrayIsArray$1(node)) {
        out = '[';
        for (i = 0; i < node.length; i++) {
            if (i) {
                out += ',';
            }
            out += stableJSONStringify(node[i]) || 'null';
        }
        return out + ']';
    }
    if (node === null) {
        return 'null';
    }
    const keys = ObjectKeys(node).sort();
    out = '';
    for (i = 0; i < keys.length; i++) {
        const key = keys[i];
        const value = stableJSONStringify(node[key]);
        if (!value) {
            continue;
        }
        if (out) {
            out += ',';
        }
        out += JSONStringify$1(key) + ':' + value;
    }
    return '{' + out + '}';
}
function generateParamConfigMetadata(name, required, resourceType, typeCheckShape, isArrayShape = false, coerceFn) {
    return {
        name,
        required,
        resourceType,
        typeCheckShape,
        isArrayShape,
        coerceFn,
    };
}
function buildAdapterValidationConfig(displayName, paramsMeta) {
    const required = paramsMeta.filter(p => p.required).map(p => p.name);
    const optional = paramsMeta.filter(p => !p.required).map(p => p.name);
    return {
        displayName,
        parameters: {
            required,
            optional,
        }
    };
}
const keyPrefix = 'data-transform';

const { isArray: ArrayIsArray } = Array;
const { stringify: JSONStringify } = JSON;
function createLink(ref) {
    return {
        __ref: serializeStructuredKey(ref),
    };
}

function validate$5(obj, path = 'TransformValidationIssueRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        if (obj.errorCode !== undefined) {
            const obj_errorCode = obj.errorCode;
            const path_errorCode = path + '.errorCode';
            if (typeof obj_errorCode !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_errorCode + '" (at "' + path_errorCode + '")');
            }
        }
        if (obj.errorMessage !== undefined) {
            const obj_errorMessage = obj.errorMessage;
            const path_errorMessage = path + '.errorMessage';
            if (typeof obj_errorMessage !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_errorMessage + '" (at "' + path_errorMessage + '")');
            }
        }
        const obj_errorSeverity = obj.errorSeverity;
        const path_errorSeverity = path + '.errorSeverity';
        if (typeof obj_errorSeverity !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_errorSeverity + '" (at "' + path_errorSeverity + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$4(obj, path = 'CdpUserRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        if (obj.name !== undefined) {
            const obj_name = obj.name;
            const path_name = path + '.name';
            if (typeof obj_name !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
            }
        }
        if (obj.profilePhotoUrl !== undefined) {
            const obj_profilePhotoUrl = obj.profilePhotoUrl;
            const path_profilePhotoUrl = path + '.profilePhotoUrl';
            if (typeof obj_profilePhotoUrl !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_profilePhotoUrl + '" (at "' + path_profilePhotoUrl + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$3(obj, path = 'CdpAssetBaseRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        if (obj.createdBy !== undefined) {
            const obj_createdBy = obj.createdBy;
            const path_createdBy = path + '.createdBy';
            const referencepath_createdByValidationError = validate$4(obj_createdBy, path_createdBy);
            if (referencepath_createdByValidationError !== null) {
                let message = 'Object doesn\'t match CdpUserRepresentation (at "' + path_createdBy + '")\n';
                message += referencepath_createdByValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        if (obj.createdDate !== undefined) {
            const obj_createdDate = obj.createdDate;
            const path_createdDate = path + '.createdDate';
            if (typeof obj_createdDate !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_createdDate + '" (at "' + path_createdDate + '")');
            }
        }
        const obj_id = obj.id;
        const path_id = path + '.id';
        if (typeof obj_id !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_id + '" (at "' + path_id + '")');
        }
        if (obj.label !== undefined) {
            const obj_label = obj.label;
            const path_label = path + '.label';
            if (typeof obj_label !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
            }
        }
        if (obj.lastModifiedBy !== undefined) {
            const obj_lastModifiedBy = obj.lastModifiedBy;
            const path_lastModifiedBy = path + '.lastModifiedBy';
            const referencepath_lastModifiedByValidationError = validate$4(obj_lastModifiedBy, path_lastModifiedBy);
            if (referencepath_lastModifiedByValidationError !== null) {
                let message = 'Object doesn\'t match CdpUserRepresentation (at "' + path_lastModifiedBy + '")\n';
                message += referencepath_lastModifiedByValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        if (obj.lastModifiedDate !== undefined) {
            const obj_lastModifiedDate = obj.lastModifiedDate;
            const path_lastModifiedDate = path + '.lastModifiedDate';
            if (typeof obj_lastModifiedDate !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_lastModifiedDate + '" (at "' + path_lastModifiedDate + '")');
            }
        }
        if (obj.name !== undefined) {
            const obj_name = obj.name;
            const path_name = path + '.name';
            if (typeof obj_name !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
            }
        }
        if (obj.namespace !== undefined) {
            const obj_namespace = obj.namespace;
            const path_namespace = path + '.namespace';
            if (typeof obj_namespace !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_namespace + '" (at "' + path_namespace + '")');
            }
        }
        if (obj.url !== undefined) {
            const obj_url = obj.url;
            const path_url = path + '.url';
            if (typeof obj_url !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_url + '" (at "' + path_url + '")');
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$2(obj, path = 'DataObjectFieldRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_isPrimaryKey = obj.isPrimaryKey;
        const path_isPrimaryKey = path + '.isPrimaryKey';
        if (typeof obj_isPrimaryKey !== 'boolean') {
            return new TypeError('Expected "boolean" but received "' + typeof obj_isPrimaryKey + '" (at "' + path_isPrimaryKey + '")');
        }
        const obj_keyQualifierField = obj.keyQualifierField;
        const path_keyQualifierField = path + '.keyQualifierField';
        if (typeof obj_keyQualifierField !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_keyQualifierField + '" (at "' + path_keyQualifierField + '")');
        }
        const obj_label = obj.label;
        const path_label = path + '.label';
        if (typeof obj_label !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_label + '" (at "' + path_label + '")');
        }
        const obj_name = obj.name;
        const path_name = path + '.name';
        if (typeof obj_name !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_name + '" (at "' + path_name + '")');
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

function validate$1(obj, path = 'DataObjectRepresentation') {
    const validateCdpAssetBaseRepresentation_validateError = validate$3(obj, path);
    if (validateCdpAssetBaseRepresentation_validateError !== null) {
        return validateCdpAssetBaseRepresentation_validateError;
    }
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        const obj_category = obj.category;
        const path_category = path + '.category';
        if (typeof obj_category !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_category + '" (at "' + path_category + '")');
        }
        if (obj.eventDateTimeFieldName !== undefined) {
            const obj_eventDateTimeFieldName = obj.eventDateTimeFieldName;
            const path_eventDateTimeFieldName = path + '.eventDateTimeFieldName';
            if (typeof obj_eventDateTimeFieldName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_eventDateTimeFieldName + '" (at "' + path_eventDateTimeFieldName + '")');
            }
        }
        const obj_fields = obj.fields;
        const path_fields = path + '.fields';
        if (!ArrayIsArray(obj_fields)) {
            return new TypeError('Expected "array" but received "' + typeof obj_fields + '" (at "' + path_fields + '")');
        }
        for (let i = 0; i < obj_fields.length; i++) {
            const obj_fields_item = obj_fields[i];
            const path_fields_item = path_fields + '[' + i + ']';
            const referencepath_fields_itemValidationError = validate$2(obj_fields_item, path_fields_item);
            if (referencepath_fields_itemValidationError !== null) {
                let message = 'Object doesn\'t match DataObjectFieldRepresentation (at "' + path_fields_item + '")\n';
                message += referencepath_fields_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                return new TypeError(message);
            }
        }
        if (obj.recordModifiedFieldName !== undefined) {
            const obj_recordModifiedFieldName = obj.recordModifiedFieldName;
            const path_recordModifiedFieldName = path + '.recordModifiedFieldName';
            if (typeof obj_recordModifiedFieldName !== 'string') {
                return new TypeError('Expected "string" but received "' + typeof obj_recordModifiedFieldName + '" (at "' + path_recordModifiedFieldName + '")');
            }
        }
        const obj_type = obj.type;
        const path_type = path + '.type';
        if (typeof obj_type !== 'string') {
            return new TypeError('Expected "string" but received "' + typeof obj_type + '" (at "' + path_type + '")');
        }
    })();
    return v_error === undefined ? null : v_error;
}

const VERSION = "21a4cd3206473ce28645099a11735bc6";
function validate(obj, path = 'DataTransformValidationRepresentation') {
    const v_error = (() => {
        if (typeof obj !== 'object' || ArrayIsArray(obj) || obj === null) {
            return new TypeError('Expected "object" but received "' + typeof obj + '" (at "' + path + '")');
        }
        if (obj.issues !== undefined) {
            const obj_issues = obj.issues;
            const path_issues = path + '.issues';
            if (!ArrayIsArray(obj_issues)) {
                return new TypeError('Expected "array" but received "' + typeof obj_issues + '" (at "' + path_issues + '")');
            }
            for (let i = 0; i < obj_issues.length; i++) {
                const obj_issues_item = obj_issues[i];
                const path_issues_item = path_issues + '[' + i + ']';
                const referencepath_issues_itemValidationError = validate$5(obj_issues_item, path_issues_item);
                if (referencepath_issues_itemValidationError !== null) {
                    let message = 'Object doesn\'t match TransformValidationIssueRepresentation (at "' + path_issues_item + '")\n';
                    message += referencepath_issues_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                    return new TypeError(message);
                }
            }
        }
        if (obj.outputDataObjects !== undefined) {
            const obj_outputDataObjects = obj.outputDataObjects;
            const path_outputDataObjects = path + '.outputDataObjects';
            if (!ArrayIsArray(obj_outputDataObjects)) {
                return new TypeError('Expected "array" but received "' + typeof obj_outputDataObjects + '" (at "' + path_outputDataObjects + '")');
            }
            for (let i = 0; i < obj_outputDataObjects.length; i++) {
                const obj_outputDataObjects_item = obj_outputDataObjects[i];
                const path_outputDataObjects_item = path_outputDataObjects + '[' + i + ']';
                const referencepath_outputDataObjects_itemValidationError = validate$1(obj_outputDataObjects_item, path_outputDataObjects_item);
                if (referencepath_outputDataObjects_itemValidationError !== null) {
                    let message = 'Object doesn\'t match DataObjectRepresentation (at "' + path_outputDataObjects_item + '")\n';
                    message += referencepath_outputDataObjects_itemValidationError.message.split('\n').map((line) => '\t' + line).join('\n');
                    return new TypeError(message);
                }
            }
        }
    })();
    return v_error === undefined ? null : v_error;
}
const RepresentationType = 'DataTransformValidationRepresentation';
function normalize(input, existing, path, luvio, store, timestamp) {
    return input;
}
const select$1 = function DataTransformValidationRepresentationSelect() {
    return {
        kind: 'Fragment',
        version: VERSION,
        private: [],
        opaque: true
    };
};
function equals(existing, incoming) {
    if (JSONStringify(incoming) !== JSONStringify(existing)) {
        return false;
    }
    return true;
}
const ingest = function DataTransformValidationRepresentationIngest(input, path, luvio, store, timestamp) {
    if (process.env.NODE_ENV !== 'production') {
        const validateError = validate(input);
        if (validateError !== null) {
            throw validateError;
        }
    }
    const key = path.fullPath;
    const ttlToUse = path.ttl !== undefined ? path.ttl : 3000000;
    ingestShape(input, path, luvio, store, timestamp, ttlToUse, key, normalize, "data-transform", VERSION, RepresentationType, equals);
    return createLink(key);
};
function getTypeCacheKeys(rootKeySet, luvio, input, fullPathFactory) {
    // root cache key (uses fullPathFactory if keyBuilderFromType isn't defined)
    const rootKey = fullPathFactory();
    rootKeySet.set(rootKey, {
        namespace: keyPrefix,
        representationName: RepresentationType,
        mergeable: false
    });
}

function select(luvio, params) {
    return select$1();
}
function keyBuilder$1(luvio, params) {
    return keyPrefix + '::DataTransformValidationRepresentation:(' + stableJSONStringify(params.body.capabilities) + '::' + 'creationType:' + params.body.creationType + '::' + (params.body.currencyIsoCode === undefined ? 'currencyIsoCode' : 'currencyIsoCode:' + params.body.currencyIsoCode) + '::' + (params.body.dataSpaceName === undefined ? 'dataSpaceName' : 'dataSpaceName:' + params.body.dataSpaceName) + '::' + stableJSONStringify(params.body.definition) + '::' + (params.body.description === undefined ? 'description' : 'description:' + params.body.description) + '::' + (params.body.label === undefined ? 'label' : 'label:' + params.body.label) + '::' + (params.body.name === undefined ? 'name' : 'name:' + params.body.name) + '::' + (params.body.primarySource === undefined ? 'primarySource' : 'primarySource:' + params.body.primarySource) + '::' + stableJSONStringify(params.body.tags) + '::' + 'type:' + params.body.type + ')';
}
function getResponseCacheKeys(storeKeyMap, luvio, resourceParams, response) {
    getTypeCacheKeys(storeKeyMap, luvio, response, () => keyBuilder$1(luvio, resourceParams));
}
function ingestSuccess(luvio, resourceParams, response, snapshotRefresh) {
    const { body } = response;
    const key = keyBuilder$1(luvio, resourceParams);
    luvio.storeIngest(key, ingest, body);
    const snapshot = luvio.storeLookup({
        recordId: key,
        node: select(),
        variables: {},
    }, snapshotRefresh);
    if (process.env.NODE_ENV !== 'production') {
        if (snapshot.state !== 'Fulfilled') {
            throw new Error('Invalid network response. Expected resource response to result in Fulfilled snapshot');
        }
    }
    deepFreeze(snapshot.data);
    return snapshot;
}
function ingestError(luvio, params, error, snapshotRefresh) {
    const key = keyBuilder$1(luvio, params);
    const errorSnapshot = luvio.errorSnapshot(error, snapshotRefresh);
    luvio.storeIngestError(key, errorSnapshot);
    return errorSnapshot;
}
function createResourceRequest(config) {
    const headers = {};
    return {
        baseUri: '/services/data/v62.0',
        basePath: '/ssot/data-transforms-validation',
        method: 'post',
        body: config.body,
        urlParams: {},
        queryParams: {},
        headers,
        priority: 'normal',
    };
}

const adapterName = 'validateDataTransforms';
const validateDataTransforms_ConfigPropertyMetadata = [
    generateParamConfigMetadata('capabilities', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('creationType', true, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('currencyIsoCode', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('dataSpaceName', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('definition', true, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('description', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('label', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('name', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('primarySource', false, 2 /* Body */, 0 /* String */),
    generateParamConfigMetadata('tags', false, 2 /* Body */, 4 /* Unsupported */),
    generateParamConfigMetadata('type', true, 2 /* Body */, 0 /* String */),
];
const validateDataTransforms_ConfigPropertyNames = /*#__PURE__*/ buildAdapterValidationConfig(adapterName, validateDataTransforms_ConfigPropertyMetadata);
const createResourceParams = /*#__PURE__*/ createResourceParams$1(validateDataTransforms_ConfigPropertyMetadata);
function keyBuilder(luvio, config) {
    const resourceParams = createResourceParams(config);
    return keyBuilder$1(luvio, resourceParams);
}
function typeCheckConfig(untrustedConfig) {
    const config = {};
    typeCheckConfig$1(untrustedConfig, config, validateDataTransforms_ConfigPropertyMetadata);
    const untrustedConfig_capabilities = untrustedConfig.capabilities;
    if (untrustedIsObject(untrustedConfig_capabilities)) {
        const untrustedConfig_capabilities_object = {};
        const untrustedConfig_capabilities_keys = Object.keys(untrustedConfig_capabilities);
        for (let i = 0, arrayLength = untrustedConfig_capabilities_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_capabilities_keys[i];
            const untrustedConfig_capabilities_prop = untrustedConfig_capabilities[key];
            if (typeof untrustedConfig_capabilities_prop === 'boolean') {
                if (untrustedConfig_capabilities_object !== undefined) {
                    untrustedConfig_capabilities_object[key] = untrustedConfig_capabilities_prop;
                }
            }
        }
        if (untrustedConfig_capabilities_object !== undefined && Object.keys(untrustedConfig_capabilities_object).length >= 0) {
            config.capabilities = untrustedConfig_capabilities_object;
        }
    }
    const untrustedConfig_definition = untrustedConfig.definition;
    if (untrustedIsObject(untrustedConfig_definition)) {
        const untrustedConfig_definition_object = {};
        const untrustedConfig_definition_keys = Object.keys(untrustedConfig_definition);
        for (let i = 0, arrayLength = untrustedConfig_definition_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_definition_keys[i];
            const untrustedConfig_definition_prop = untrustedConfig_definition[key];
            if (untrustedConfig_definition_object !== undefined) {
                untrustedConfig_definition_object[key] = untrustedConfig_definition_prop;
            }
        }
        if (untrustedConfig_definition_object !== undefined && Object.keys(untrustedConfig_definition_object).length >= 0) {
            config.definition = untrustedConfig_definition_object;
        }
    }
    const untrustedConfig_tags = untrustedConfig.tags;
    if (untrustedIsObject(untrustedConfig_tags)) {
        const untrustedConfig_tags_object = {};
        const untrustedConfig_tags_keys = Object.keys(untrustedConfig_tags);
        for (let i = 0, arrayLength = untrustedConfig_tags_keys.length; i < arrayLength; i++) {
            const key = untrustedConfig_tags_keys[i];
            const untrustedConfig_tags_prop = untrustedConfig_tags[key];
            if (typeof untrustedConfig_tags_prop === 'string') {
                if (untrustedConfig_tags_object !== undefined) {
                    untrustedConfig_tags_object[key] = untrustedConfig_tags_prop;
                }
            }
        }
        if (untrustedConfig_tags_object !== undefined && Object.keys(untrustedConfig_tags_object).length >= 0) {
            config.tags = untrustedConfig_tags_object;
        }
    }
    return config;
}
function validateAdapterConfig(untrustedConfig, configPropertyNames) {
    if (!untrustedIsObject(untrustedConfig)) {
        return null;
    }
    if (process.env.NODE_ENV !== 'production') {
        validateConfig(untrustedConfig, configPropertyNames);
    }
    const config = typeCheckConfig(untrustedConfig);
    if (!areRequiredParametersPresent(config, configPropertyNames)) {
        return null;
    }
    return config;
}
function adapterFragment(luvio, config) {
    createResourceParams(config);
    return select();
}
function onFetchResponseSuccess(luvio, config, resourceParams, response) {
    const snapshot = ingestSuccess(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function onFetchResponseError(luvio, config, resourceParams, response) {
    const snapshot = ingestError(luvio, resourceParams, response, {
        config,
        resolve: () => buildNetworkSnapshot(luvio, config, snapshotRefreshOptions)
    });
    return luvio.storeBroadcast().then(() => snapshot);
}
function buildNetworkSnapshot(luvio, config, options) {
    const resourceParams = createResourceParams(config);
    const request = createResourceRequest(resourceParams);
    return luvio.dispatchResourceRequest(request, options)
        .then((response) => {
        return luvio.handleSuccessResponse(() => onFetchResponseSuccess(luvio, config, resourceParams, response), () => {
            const cache = new StoreKeyMap();
            getResponseCacheKeys(cache, luvio, resourceParams, response.body);
            return cache;
        });
    }, (response) => {
        return luvio.handleErrorResponse(() => onFetchResponseError(luvio, config, resourceParams, response));
    });
}
function buildNetworkSnapshotCachePolicy(context, coercedAdapterRequestContext) {
    return buildNetworkSnapshotCachePolicy$1(context, coercedAdapterRequestContext, buildNetworkSnapshot, 'get', false);
}
function buildCachedSnapshotCachePolicy(context, storeLookup) {
    const { luvio, config } = context;
    const selector = {
        recordId: keyBuilder(luvio, config),
        node: adapterFragment(luvio, config),
        variables: {},
    };
    const cacheSnapshot = storeLookup(selector, {
        config,
        resolve: () => buildNetworkSnapshot(luvio, config, snapshotRefreshOptions)
    });
    return cacheSnapshot;
}
const validateDataTransformsAdapterFactory = (luvio) => function dataTransform__validateDataTransforms(untrustedConfig, requestContext) {
    const config = validateAdapterConfig(untrustedConfig, validateDataTransforms_ConfigPropertyNames);
    // Invalid or incomplete config
    if (config === null) {
        return null;
    }
    return luvio.applyCachePolicy((requestContext || {}), { config, luvio }, // BuildSnapshotContext
    buildCachedSnapshotCachePolicy, buildNetworkSnapshotCachePolicy);
};

export { validateDataTransformsAdapterFactory };
